Welcome to ufoLib2's documentation!
===================================

ufoLib2 is meant to be a thin representation of the Unified Font Object (UFO) version 3 data model, intended for programmatic manipulation and fast batch processing of UFOs.

It resembles the `defcon <https://github.com/robotools/defcon>`_ library, but does without notifications, the layout engine and other support classes. Where useful and possible, ufoLib2 tries to be API-compatible with defcon.

See http://unifiedfontobject.org/versions/ufo3/ for the specification of the on-disk data structure.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   explanations
   reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
